# coding: utf-8

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from .configuration import Configuration
from .api_client import ApiClient


class AddressesNLApi(object):
    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def addresses_nl_get_by_city(self, city, **kwargs):
        """
        Get a Dutch Address based on City
        Retrieves info for a Dutch Address based on a City
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_city(city, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str city: Name of City (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_by_city_with_http_info(city, **kwargs)
        else:
            (data) = self.addresses_nl_get_by_city_with_http_info(city, **kwargs)
            return data

    def addresses_nl_get_by_city_with_http_info(self, city, **kwargs):
        """
        Get a Dutch Address based on City
        Retrieves info for a Dutch Address based on a City
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_city_with_http_info(city, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str city: Name of City (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['city']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_by_city" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'city' is set
        if ('city' not in params) or (params['city'] is None):
            raise ValueError("Missing the required parameter `city` when calling `addresses_nl_get_by_city`")

        if 'city' in params and len(params['city']) > 30:
            raise ValueError("Invalid value for parameter `city` when calling `addresses_nl_get_by_city`, length must be less than or equal to `30`")
        if 'city' in params and len(params['city']) < 2:
            raise ValueError("Invalid value for parameter `city` when calling `addresses_nl_get_by_city`, length must be greater than or equal to `2`")

        collection_formats = {}

        resource_path = '/addresses/nl/{city}'.replace('{format}', 'json')
        path_params = {}
        if 'city' in params:
            path_params['city'] = params['city']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse200',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_by_city_street(self, city, street, **kwargs):
        """
        Get a Dutch Address based on City and Street
        Retrieves info for a Dutch Address based on a City and Street
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_city_street(city, street, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str city: Name of City (required)
        :param str street: Name of Street (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_by_city_street_with_http_info(city, street, **kwargs)
        else:
            (data) = self.addresses_nl_get_by_city_street_with_http_info(city, street, **kwargs)
            return data

    def addresses_nl_get_by_city_street_with_http_info(self, city, street, **kwargs):
        """
        Get a Dutch Address based on City and Street
        Retrieves info for a Dutch Address based on a City and Street
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_city_street_with_http_info(city, street, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str city: Name of City (required)
        :param str street: Name of Street (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['city', 'street']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_by_city_street" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'city' is set
        if ('city' not in params) or (params['city'] is None):
            raise ValueError("Missing the required parameter `city` when calling `addresses_nl_get_by_city_street`")
        # verify the required parameter 'street' is set
        if ('street' not in params) or (params['street'] is None):
            raise ValueError("Missing the required parameter `street` when calling `addresses_nl_get_by_city_street`")

        if 'city' in params and len(params['city']) > 30:
            raise ValueError("Invalid value for parameter `city` when calling `addresses_nl_get_by_city_street`, length must be less than or equal to `30`")
        if 'city' in params and len(params['city']) < 2:
            raise ValueError("Invalid value for parameter `city` when calling `addresses_nl_get_by_city_street`, length must be greater than or equal to `2`")
        if 'street' in params and len(params['street']) > 50:
            raise ValueError("Invalid value for parameter `street` when calling `addresses_nl_get_by_city_street`, length must be less than or equal to `50`")
        if 'street' in params and len(params['street']) < 1:
            raise ValueError("Invalid value for parameter `street` when calling `addresses_nl_get_by_city_street`, length must be greater than or equal to `1`")

        collection_formats = {}

        resource_path = '/addresses/nl/{city}/{street}'.replace('{format}', 'json')
        path_params = {}
        if 'city' in params:
            path_params['city'] = params['city']
        if 'street' in params:
            path_params['street'] = params['street']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse200',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_by_city_street_house_number(self, city, street, house_number, **kwargs):
        """
        Get a Dutch Address based on City, Street and Housenumber
        Retrieves info for a Dutch Address based on a City, Street and Housenumber
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_city_street_house_number(city, street, house_number, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str city: Name of City (required)
        :param str street: Name of Street (required)
        :param int house_number: Housenumber (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_by_city_street_house_number_with_http_info(city, street, house_number, **kwargs)
        else:
            (data) = self.addresses_nl_get_by_city_street_house_number_with_http_info(city, street, house_number, **kwargs)
            return data

    def addresses_nl_get_by_city_street_house_number_with_http_info(self, city, street, house_number, **kwargs):
        """
        Get a Dutch Address based on City, Street and Housenumber
        Retrieves info for a Dutch Address based on a City, Street and Housenumber
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_city_street_house_number_with_http_info(city, street, house_number, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str city: Name of City (required)
        :param str street: Name of Street (required)
        :param int house_number: Housenumber (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['city', 'street', 'house_number']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_by_city_street_house_number" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'city' is set
        if ('city' not in params) or (params['city'] is None):
            raise ValueError("Missing the required parameter `city` when calling `addresses_nl_get_by_city_street_house_number`")
        # verify the required parameter 'street' is set
        if ('street' not in params) or (params['street'] is None):
            raise ValueError("Missing the required parameter `street` when calling `addresses_nl_get_by_city_street_house_number`")
        # verify the required parameter 'house_number' is set
        if ('house_number' not in params) or (params['house_number'] is None):
            raise ValueError("Missing the required parameter `house_number` when calling `addresses_nl_get_by_city_street_house_number`")

        if 'city' in params and len(params['city']) > 30:
            raise ValueError("Invalid value for parameter `city` when calling `addresses_nl_get_by_city_street_house_number`, length must be less than or equal to `30`")
        if 'city' in params and len(params['city']) < 2:
            raise ValueError("Invalid value for parameter `city` when calling `addresses_nl_get_by_city_street_house_number`, length must be greater than or equal to `2`")
        if 'street' in params and len(params['street']) > 50:
            raise ValueError("Invalid value for parameter `street` when calling `addresses_nl_get_by_city_street_house_number`, length must be less than or equal to `50`")
        if 'street' in params and len(params['street']) < 1:
            raise ValueError("Invalid value for parameter `street` when calling `addresses_nl_get_by_city_street_house_number`, length must be greater than or equal to `1`")
        if 'house_number' in params and params['house_number'] > 99999:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_by_city_street_house_number`, must be a value less than or equal to `99999`")
        if 'house_number' in params and params['house_number'] < 0:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_by_city_street_house_number`, must be a value greater than or equal to `0`")

        collection_formats = {}

        resource_path = '/addresses/nl/{city}/{street}/{houseNumber}'.replace('{format}', 'json')
        path_params = {}
        if 'city' in params:
            path_params['city'] = params['city']
        if 'street' in params:
            path_params['street'] = params['street']
        if 'house_number' in params:
            path_params['houseNumber'] = params['house_number']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse200',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_by_city_street_house_number_and_suffix(self, city, street, house_number, house_number_suffix, **kwargs):
        """
        Get a Dutch Address based on City, Street and Housenumber and Suffix
        Retrieves info for a Dutch Address based on a City, Street and Housenumber and HouseNumber suffix
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_city_street_house_number_and_suffix(city, street, house_number, house_number_suffix, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str city: Name of City (required)
        :param str street: Name of Street (required)
        :param int house_number: Housenumber (required)
        :param str house_number_suffix: HouseNumber Suffix (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_by_city_street_house_number_and_suffix_with_http_info(city, street, house_number, house_number_suffix, **kwargs)
        else:
            (data) = self.addresses_nl_get_by_city_street_house_number_and_suffix_with_http_info(city, street, house_number, house_number_suffix, **kwargs)
            return data

    def addresses_nl_get_by_city_street_house_number_and_suffix_with_http_info(self, city, street, house_number, house_number_suffix, **kwargs):
        """
        Get a Dutch Address based on City, Street and Housenumber and Suffix
        Retrieves info for a Dutch Address based on a City, Street and Housenumber and HouseNumber suffix
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_city_street_house_number_and_suffix_with_http_info(city, street, house_number, house_number_suffix, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str city: Name of City (required)
        :param str street: Name of Street (required)
        :param int house_number: Housenumber (required)
        :param str house_number_suffix: HouseNumber Suffix (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['city', 'street', 'house_number', 'house_number_suffix']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_by_city_street_house_number_and_suffix" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'city' is set
        if ('city' not in params) or (params['city'] is None):
            raise ValueError("Missing the required parameter `city` when calling `addresses_nl_get_by_city_street_house_number_and_suffix`")
        # verify the required parameter 'street' is set
        if ('street' not in params) or (params['street'] is None):
            raise ValueError("Missing the required parameter `street` when calling `addresses_nl_get_by_city_street_house_number_and_suffix`")
        # verify the required parameter 'house_number' is set
        if ('house_number' not in params) or (params['house_number'] is None):
            raise ValueError("Missing the required parameter `house_number` when calling `addresses_nl_get_by_city_street_house_number_and_suffix`")
        # verify the required parameter 'house_number_suffix' is set
        if ('house_number_suffix' not in params) or (params['house_number_suffix'] is None):
            raise ValueError("Missing the required parameter `house_number_suffix` when calling `addresses_nl_get_by_city_street_house_number_and_suffix`")

        if 'city' in params and len(params['city']) > 30:
            raise ValueError("Invalid value for parameter `city` when calling `addresses_nl_get_by_city_street_house_number_and_suffix`, length must be less than or equal to `30`")
        if 'city' in params and len(params['city']) < 2:
            raise ValueError("Invalid value for parameter `city` when calling `addresses_nl_get_by_city_street_house_number_and_suffix`, length must be greater than or equal to `2`")
        if 'street' in params and len(params['street']) > 50:
            raise ValueError("Invalid value for parameter `street` when calling `addresses_nl_get_by_city_street_house_number_and_suffix`, length must be less than or equal to `50`")
        if 'street' in params and len(params['street']) < 1:
            raise ValueError("Invalid value for parameter `street` when calling `addresses_nl_get_by_city_street_house_number_and_suffix`, length must be greater than or equal to `1`")
        if 'house_number' in params and params['house_number'] > 99999:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_by_city_street_house_number_and_suffix`, must be a value less than or equal to `99999`")
        if 'house_number' in params and params['house_number'] < 0:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_by_city_street_house_number_and_suffix`, must be a value greater than or equal to `0`")

        collection_formats = {}

        resource_path = '/addresses/nl/{city}/{street}/{houseNumber}/{houseNumberSuffix}'.replace('{format}', 'json')
        path_params = {}
        if 'city' in params:
            path_params['city'] = params['city']
        if 'street' in params:
            path_params['street'] = params['street']
        if 'house_number' in params:
            path_params['houseNumber'] = params['house_number']
        if 'house_number_suffix' in params:
            path_params['houseNumberSuffix'] = params['house_number_suffix']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse200',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_by_postal_code(self, postal_code, **kwargs):
        """
        Get a Dutch Address based on Postal Code
        Retrieves info for a Dutch Address based on a Postal Code
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_postal_code(postal_code, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_by_postal_code_with_http_info(postal_code, **kwargs)
        else:
            (data) = self.addresses_nl_get_by_postal_code_with_http_info(postal_code, **kwargs)
            return data

    def addresses_nl_get_by_postal_code_with_http_info(self, postal_code, **kwargs):
        """
        Get a Dutch Address based on Postal Code
        Retrieves info for a Dutch Address based on a Postal Code
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_postal_code_with_http_info(postal_code, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['postal_code']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_by_postal_code" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'postal_code' is set
        if ('postal_code' not in params) or (params['postal_code'] is None):
            raise ValueError("Missing the required parameter `postal_code` when calling `addresses_nl_get_by_postal_code`")

        if 'postal_code' in params and len(params['postal_code']) > 7:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_by_postal_code`, length must be less than or equal to `7`")
        if 'postal_code' in params and len(params['postal_code']) < 6:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_by_postal_code`, length must be greater than or equal to `6`")
        if 'postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['postal_code']):
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_by_postal_code`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")

        collection_formats = {}

        resource_path = '/addresses/nl/{postalCode}'.replace('{format}', 'json')
        path_params = {}
        if 'postal_code' in params:
            path_params['postalCode'] = params['postal_code']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse200',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_by_postal_code_house_number(self, postal_code, house_number, **kwargs):
        """
        Get a Dutch Address based on Postal Code and Housenumber
        Retrieves info for a Dutch Address based on a Postal Code and Housenumber
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_postal_code_house_number(postal_code, house_number, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_by_postal_code_house_number_with_http_info(postal_code, house_number, **kwargs)
        else:
            (data) = self.addresses_nl_get_by_postal_code_house_number_with_http_info(postal_code, house_number, **kwargs)
            return data

    def addresses_nl_get_by_postal_code_house_number_with_http_info(self, postal_code, house_number, **kwargs):
        """
        Get a Dutch Address based on Postal Code and Housenumber
        Retrieves info for a Dutch Address based on a Postal Code and Housenumber
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_postal_code_house_number_with_http_info(postal_code, house_number, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['postal_code', 'house_number']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_by_postal_code_house_number" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'postal_code' is set
        if ('postal_code' not in params) or (params['postal_code'] is None):
            raise ValueError("Missing the required parameter `postal_code` when calling `addresses_nl_get_by_postal_code_house_number`")
        # verify the required parameter 'house_number' is set
        if ('house_number' not in params) or (params['house_number'] is None):
            raise ValueError("Missing the required parameter `house_number` when calling `addresses_nl_get_by_postal_code_house_number`")

        if 'postal_code' in params and len(params['postal_code']) > 7:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_by_postal_code_house_number`, length must be less than or equal to `7`")
        if 'postal_code' in params and len(params['postal_code']) < 6:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_by_postal_code_house_number`, length must be greater than or equal to `6`")
        if 'postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['postal_code']):
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_by_postal_code_house_number`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'house_number' in params and params['house_number'] > 99999:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_by_postal_code_house_number`, must be a value less than or equal to `99999`")
        if 'house_number' in params and params['house_number'] < 0:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_by_postal_code_house_number`, must be a value greater than or equal to `0`")

        collection_formats = {}

        resource_path = '/addresses/nl/{postalCode}/{houseNumber}'.replace('{format}', 'json')
        path_params = {}
        if 'postal_code' in params:
            path_params['postalCode'] = params['postal_code']
        if 'house_number' in params:
            path_params['houseNumber'] = params['house_number']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse200',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_by_postal_code_house_number_and_suffix(self, postal_code, house_number, house_number_suffix, **kwargs):
        """
        Get a Dutch Address based on Postal Code, Housenumber and HouseNumber suffix
        Retrieves info for a Dutch Address based on a Postal Code, Housenumber and HouseNumber suffix
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_postal_code_house_number_and_suffix(postal_code, house_number, house_number_suffix, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str house_number_suffix: HouseNumber Suffix (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_by_postal_code_house_number_and_suffix_with_http_info(postal_code, house_number, house_number_suffix, **kwargs)
        else:
            (data) = self.addresses_nl_get_by_postal_code_house_number_and_suffix_with_http_info(postal_code, house_number, house_number_suffix, **kwargs)
            return data

    def addresses_nl_get_by_postal_code_house_number_and_suffix_with_http_info(self, postal_code, house_number, house_number_suffix, **kwargs):
        """
        Get a Dutch Address based on Postal Code, Housenumber and HouseNumber suffix
        Retrieves info for a Dutch Address based on a Postal Code, Housenumber and HouseNumber suffix
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_by_postal_code_house_number_and_suffix_with_http_info(postal_code, house_number, house_number_suffix, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str house_number_suffix: HouseNumber Suffix (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['postal_code', 'house_number', 'house_number_suffix']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_by_postal_code_house_number_and_suffix" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'postal_code' is set
        if ('postal_code' not in params) or (params['postal_code'] is None):
            raise ValueError("Missing the required parameter `postal_code` when calling `addresses_nl_get_by_postal_code_house_number_and_suffix`")
        # verify the required parameter 'house_number' is set
        if ('house_number' not in params) or (params['house_number'] is None):
            raise ValueError("Missing the required parameter `house_number` when calling `addresses_nl_get_by_postal_code_house_number_and_suffix`")
        # verify the required parameter 'house_number_suffix' is set
        if ('house_number_suffix' not in params) or (params['house_number_suffix'] is None):
            raise ValueError("Missing the required parameter `house_number_suffix` when calling `addresses_nl_get_by_postal_code_house_number_and_suffix`")

        if 'postal_code' in params and len(params['postal_code']) > 7:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_by_postal_code_house_number_and_suffix`, length must be less than or equal to `7`")
        if 'postal_code' in params and len(params['postal_code']) < 6:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_by_postal_code_house_number_and_suffix`, length must be greater than or equal to `6`")
        if 'postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['postal_code']):
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_by_postal_code_house_number_and_suffix`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'house_number' in params and params['house_number'] > 99999:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_by_postal_code_house_number_and_suffix`, must be a value less than or equal to `99999`")
        if 'house_number' in params and params['house_number'] < 0:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_by_postal_code_house_number_and_suffix`, must be a value greater than or equal to `0`")

        collection_formats = {}

        resource_path = '/addresses/nl/{postalCode}/{houseNumber}/{houseNumberSuffix}'.replace('{format}', 'json')
        path_params = {}
        if 'postal_code' in params:
            path_params['postalCode'] = params['postal_code']
        if 'house_number' in params:
            path_params['houseNumber'] = params['house_number']
        if 'house_number_suffix' in params:
            path_params['houseNumberSuffix'] = params['house_number_suffix']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse200',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1(self, postal_code, house_number, house_number_suffix, other_postal_code, **kwargs):
        """
        Get the distance in meters from one address based on Postal Code, HouseNumber and HouseNumber Suffix to another based on Postal Code
        Retrieves the distance in meters from one address based on Postal Code, HouseNumber and HouseNumber Suffix to another based on Postal Code
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1(postal_code, house_number, house_number_suffix, other_postal_code, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str house_number_suffix: HouseNumber Suffix (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1_with_http_info(postal_code, house_number, house_number_suffix, other_postal_code, **kwargs)
        else:
            (data) = self.addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1_with_http_info(postal_code, house_number, house_number_suffix, other_postal_code, **kwargs)
            return data

    def addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1_with_http_info(self, postal_code, house_number, house_number_suffix, other_postal_code, **kwargs):
        """
        Get the distance in meters from one address based on Postal Code, HouseNumber and HouseNumber Suffix to another based on Postal Code
        Retrieves the distance in meters from one address based on Postal Code, HouseNumber and HouseNumber Suffix to another based on Postal Code
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1_with_http_info(postal_code, house_number, house_number_suffix, other_postal_code, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str house_number_suffix: HouseNumber Suffix (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['postal_code', 'house_number', 'house_number_suffix', 'other_postal_code']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'postal_code' is set
        if ('postal_code' not in params) or (params['postal_code'] is None):
            raise ValueError("Missing the required parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1`")
        # verify the required parameter 'house_number' is set
        if ('house_number' not in params) or (params['house_number'] is None):
            raise ValueError("Missing the required parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1`")
        # verify the required parameter 'house_number_suffix' is set
        if ('house_number_suffix' not in params) or (params['house_number_suffix'] is None):
            raise ValueError("Missing the required parameter `house_number_suffix` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1`")
        # verify the required parameter 'other_postal_code' is set
        if ('other_postal_code' not in params) or (params['other_postal_code'] is None):
            raise ValueError("Missing the required parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1`")

        if 'postal_code' in params and len(params['postal_code']) > 7:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1`, length must be less than or equal to `7`")
        if 'postal_code' in params and len(params['postal_code']) < 6:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1`, length must be greater than or equal to `6`")
        if 'postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['postal_code']):
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'house_number' in params and params['house_number'] > 99999:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1`, must be a value less than or equal to `99999`")
        if 'house_number' in params and params['house_number'] < 0:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1`, must be a value greater than or equal to `0`")
        if 'other_postal_code' in params and len(params['other_postal_code']) > 7:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1`, length must be less than or equal to `7`")
        if 'other_postal_code' in params and len(params['other_postal_code']) < 6:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1`, length must be greater than or equal to `6`")
        if 'other_postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['other_postal_code']):
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number1`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")

        collection_formats = {}

        resource_path = '/addresses/nl/{postalCode}/{houseNumber}/{houseNumberSuffix}/distances/{otherPostalCode}'.replace('{format}', 'json')
        path_params = {}
        if 'postal_code' in params:
            path_params['postalCode'] = params['postal_code']
        if 'house_number' in params:
            path_params['houseNumber'] = params['house_number']
        if 'house_number_suffix' in params:
            path_params['houseNumberSuffix'] = params['house_number_suffix']
        if 'other_postal_code' in params:
            path_params['otherPostalCode'] = params['other_postal_code']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse2001',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2(self, postal_code, house_number, house_number_suffix, other_postal_code, other_house_number, **kwargs):
        """
        Get the distance in meters from one address based on Postal Code, HouseNumber and HouseNumber Suffix to another based on Postal Code and HouseNumber
        Retrieves the distance in meters from one address based on Postal Code, HouseNumber and HouseNumber Suffix to another based on Postal Code and Housenumber
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2(postal_code, house_number, house_number_suffix, other_postal_code, other_house_number, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str house_number_suffix: HouseNumber Suffix (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int other_house_number: Housenumber (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2_with_http_info(postal_code, house_number, house_number_suffix, other_postal_code, other_house_number, **kwargs)
        else:
            (data) = self.addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2_with_http_info(postal_code, house_number, house_number_suffix, other_postal_code, other_house_number, **kwargs)
            return data

    def addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2_with_http_info(self, postal_code, house_number, house_number_suffix, other_postal_code, other_house_number, **kwargs):
        """
        Get the distance in meters from one address based on Postal Code, HouseNumber and HouseNumber Suffix to another based on Postal Code and HouseNumber
        Retrieves the distance in meters from one address based on Postal Code, HouseNumber and HouseNumber Suffix to another based on Postal Code and Housenumber
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2_with_http_info(postal_code, house_number, house_number_suffix, other_postal_code, other_house_number, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str house_number_suffix: HouseNumber Suffix (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int other_house_number: Housenumber (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['postal_code', 'house_number', 'house_number_suffix', 'other_postal_code', 'other_house_number']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'postal_code' is set
        if ('postal_code' not in params) or (params['postal_code'] is None):
            raise ValueError("Missing the required parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`")
        # verify the required parameter 'house_number' is set
        if ('house_number' not in params) or (params['house_number'] is None):
            raise ValueError("Missing the required parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`")
        # verify the required parameter 'house_number_suffix' is set
        if ('house_number_suffix' not in params) or (params['house_number_suffix'] is None):
            raise ValueError("Missing the required parameter `house_number_suffix` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`")
        # verify the required parameter 'other_postal_code' is set
        if ('other_postal_code' not in params) or (params['other_postal_code'] is None):
            raise ValueError("Missing the required parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`")
        # verify the required parameter 'other_house_number' is set
        if ('other_house_number' not in params) or (params['other_house_number'] is None):
            raise ValueError("Missing the required parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`")

        if 'postal_code' in params and len(params['postal_code']) > 7:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`, length must be less than or equal to `7`")
        if 'postal_code' in params and len(params['postal_code']) < 6:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`, length must be greater than or equal to `6`")
        if 'postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['postal_code']):
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'house_number' in params and params['house_number'] > 99999:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`, must be a value less than or equal to `99999`")
        if 'house_number' in params and params['house_number'] < 0:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`, must be a value greater than or equal to `0`")
        if 'other_postal_code' in params and len(params['other_postal_code']) > 7:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`, length must be less than or equal to `7`")
        if 'other_postal_code' in params and len(params['other_postal_code']) < 6:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`, length must be greater than or equal to `6`")
        if 'other_postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['other_postal_code']):
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'other_house_number' in params and params['other_house_number'] > 99999:
            raise ValueError("Invalid value for parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`, must be a value less than or equal to `99999`")
        if 'other_house_number' in params and params['other_house_number'] < 0:
            raise ValueError("Invalid value for parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number2`, must be a value greater than or equal to `0`")

        collection_formats = {}

        resource_path = '/addresses/nl/{postalCode}/{houseNumber}/{houseNumberSuffix}/distances/{otherPostalCode}/{otherHouseNumber}'.replace('{format}', 'json')
        path_params = {}
        if 'postal_code' in params:
            path_params['postalCode'] = params['postal_code']
        if 'house_number' in params:
            path_params['houseNumber'] = params['house_number']
        if 'house_number_suffix' in params:
            path_params['houseNumberSuffix'] = params['house_number_suffix']
        if 'other_postal_code' in params:
            path_params['otherPostalCode'] = params['other_postal_code']
        if 'other_house_number' in params:
            path_params['otherHouseNumber'] = params['other_house_number']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse2001',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix(self, postal_code, house_number, house_number_suffix, other_postal_code, other_house_number, other_house_number_suffix, **kwargs):
        """
        Get the distance in meters from one address to another based on Postal Code, HouseNumber and HouseNumber Suffix
        Retrieves the distance in meters from one address to another based on Postal Code, HouseNumber and HouseNumber Suffix
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix(postal_code, house_number, house_number_suffix, other_postal_code, other_house_number, other_house_number_suffix, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str house_number_suffix: HouseNumber Suffix (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int other_house_number: Housenumber (required)
        :param str other_house_number_suffix: HouseNumber Suffix (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix_with_http_info(postal_code, house_number, house_number_suffix, other_postal_code, other_house_number, other_house_number_suffix, **kwargs)
        else:
            (data) = self.addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix_with_http_info(postal_code, house_number, house_number_suffix, other_postal_code, other_house_number, other_house_number_suffix, **kwargs)
            return data

    def addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix_with_http_info(self, postal_code, house_number, house_number_suffix, other_postal_code, other_house_number, other_house_number_suffix, **kwargs):
        """
        Get the distance in meters from one address to another based on Postal Code, HouseNumber and HouseNumber Suffix
        Retrieves the distance in meters from one address to another based on Postal Code, HouseNumber and HouseNumber Suffix
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix_with_http_info(postal_code, house_number, house_number_suffix, other_postal_code, other_house_number, other_house_number_suffix, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str house_number_suffix: HouseNumber Suffix (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int other_house_number: Housenumber (required)
        :param str other_house_number_suffix: HouseNumber Suffix (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['postal_code', 'house_number', 'house_number_suffix', 'other_postal_code', 'other_house_number', 'other_house_number_suffix']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'postal_code' is set
        if ('postal_code' not in params) or (params['postal_code'] is None):
            raise ValueError("Missing the required parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`")
        # verify the required parameter 'house_number' is set
        if ('house_number' not in params) or (params['house_number'] is None):
            raise ValueError("Missing the required parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`")
        # verify the required parameter 'house_number_suffix' is set
        if ('house_number_suffix' not in params) or (params['house_number_suffix'] is None):
            raise ValueError("Missing the required parameter `house_number_suffix` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`")
        # verify the required parameter 'other_postal_code' is set
        if ('other_postal_code' not in params) or (params['other_postal_code'] is None):
            raise ValueError("Missing the required parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`")
        # verify the required parameter 'other_house_number' is set
        if ('other_house_number' not in params) or (params['other_house_number'] is None):
            raise ValueError("Missing the required parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`")
        # verify the required parameter 'other_house_number_suffix' is set
        if ('other_house_number_suffix' not in params) or (params['other_house_number_suffix'] is None):
            raise ValueError("Missing the required parameter `other_house_number_suffix` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`")

        if 'postal_code' in params and len(params['postal_code']) > 7:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`, length must be less than or equal to `7`")
        if 'postal_code' in params and len(params['postal_code']) < 6:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`, length must be greater than or equal to `6`")
        if 'postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['postal_code']):
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'house_number' in params and params['house_number'] > 99999:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`, must be a value less than or equal to `99999`")
        if 'house_number' in params and params['house_number'] < 0:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`, must be a value greater than or equal to `0`")
        if 'other_postal_code' in params and len(params['other_postal_code']) > 7:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`, length must be less than or equal to `7`")
        if 'other_postal_code' in params and len(params['other_postal_code']) < 6:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`, length must be greater than or equal to `6`")
        if 'other_postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['other_postal_code']):
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'other_house_number' in params and params['other_house_number'] > 99999:
            raise ValueError("Invalid value for parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`, must be a value less than or equal to `99999`")
        if 'other_house_number' in params and params['other_house_number'] < 0:
            raise ValueError("Invalid value for parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_and_suffix_to_postal_code_house_number_and_suffix`, must be a value greater than or equal to `0`")

        collection_formats = {}

        resource_path = '/addresses/nl/{postalCode}/{houseNumber}/{houseNumberSuffix}/distances/{otherPostalCode}/{otherHouseNumber}/{otherHouseNumberSuffix}'.replace('{format}', 'json')
        path_params = {}
        if 'postal_code' in params:
            path_params['postalCode'] = params['postal_code']
        if 'house_number' in params:
            path_params['houseNumber'] = params['house_number']
        if 'house_number_suffix' in params:
            path_params['houseNumberSuffix'] = params['house_number_suffix']
        if 'other_postal_code' in params:
            path_params['otherPostalCode'] = params['other_postal_code']
        if 'other_house_number' in params:
            path_params['otherHouseNumber'] = params['other_house_number']
        if 'other_house_number_suffix' in params:
            path_params['otherHouseNumberSuffix'] = params['other_house_number_suffix']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse2001',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_distance_from_postal_code_house_number_to_postal_code(self, postal_code, house_number, other_postal_code, **kwargs):
        """
        Get the distance in meters from one address to another based on Postal Code
        Retrieves the distance in meters from one address to another based on Postal Code
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_house_number_to_postal_code(postal_code, house_number, other_postal_code, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_with_http_info(postal_code, house_number, other_postal_code, **kwargs)
        else:
            (data) = self.addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_with_http_info(postal_code, house_number, other_postal_code, **kwargs)
            return data

    def addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_with_http_info(self, postal_code, house_number, other_postal_code, **kwargs):
        """
        Get the distance in meters from one address to another based on Postal Code
        Retrieves the distance in meters from one address to another based on Postal Code
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_with_http_info(postal_code, house_number, other_postal_code, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['postal_code', 'house_number', 'other_postal_code']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_distance_from_postal_code_house_number_to_postal_code" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'postal_code' is set
        if ('postal_code' not in params) or (params['postal_code'] is None):
            raise ValueError("Missing the required parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code`")
        # verify the required parameter 'house_number' is set
        if ('house_number' not in params) or (params['house_number'] is None):
            raise ValueError("Missing the required parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code`")
        # verify the required parameter 'other_postal_code' is set
        if ('other_postal_code' not in params) or (params['other_postal_code'] is None):
            raise ValueError("Missing the required parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code`")

        if 'postal_code' in params and len(params['postal_code']) > 7:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code`, length must be less than or equal to `7`")
        if 'postal_code' in params and len(params['postal_code']) < 6:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code`, length must be greater than or equal to `6`")
        if 'postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['postal_code']):
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'house_number' in params and params['house_number'] > 99999:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code`, must be a value less than or equal to `99999`")
        if 'house_number' in params and params['house_number'] < 0:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code`, must be a value greater than or equal to `0`")
        if 'other_postal_code' in params and len(params['other_postal_code']) > 7:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code`, length must be less than or equal to `7`")
        if 'other_postal_code' in params and len(params['other_postal_code']) < 6:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code`, length must be greater than or equal to `6`")
        if 'other_postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['other_postal_code']):
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")

        collection_formats = {}

        resource_path = '/addresses/nl/{postalCode}/{houseNumber}/distances/{otherPostalCode}'.replace('{format}', 'json')
        path_params = {}
        if 'postal_code' in params:
            path_params['postalCode'] = params['postal_code']
        if 'house_number' in params:
            path_params['houseNumber'] = params['house_number']
        if 'other_postal_code' in params:
            path_params['otherPostalCode'] = params['other_postal_code']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse2001',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number(self, postal_code, house_number, other_postal_code, other_house_number, **kwargs):
        """
        Get the distance in meters from one address to another based on Postal Code and HouseNumber
        Retrieves the distance in meters from one address to another based on Postal Code and HouseNumber
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number(postal_code, house_number, other_postal_code, other_house_number, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int other_house_number: Housenumber (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_with_http_info(postal_code, house_number, other_postal_code, other_house_number, **kwargs)
        else:
            (data) = self.addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_with_http_info(postal_code, house_number, other_postal_code, other_house_number, **kwargs)
            return data

    def addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_with_http_info(self, postal_code, house_number, other_postal_code, other_house_number, **kwargs):
        """
        Get the distance in meters from one address to another based on Postal Code and HouseNumber
        Retrieves the distance in meters from one address to another based on Postal Code and HouseNumber
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_with_http_info(postal_code, house_number, other_postal_code, other_house_number, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int other_house_number: Housenumber (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['postal_code', 'house_number', 'other_postal_code', 'other_house_number']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'postal_code' is set
        if ('postal_code' not in params) or (params['postal_code'] is None):
            raise ValueError("Missing the required parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`")
        # verify the required parameter 'house_number' is set
        if ('house_number' not in params) or (params['house_number'] is None):
            raise ValueError("Missing the required parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`")
        # verify the required parameter 'other_postal_code' is set
        if ('other_postal_code' not in params) or (params['other_postal_code'] is None):
            raise ValueError("Missing the required parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`")
        # verify the required parameter 'other_house_number' is set
        if ('other_house_number' not in params) or (params['other_house_number'] is None):
            raise ValueError("Missing the required parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`")

        if 'postal_code' in params and len(params['postal_code']) > 7:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`, length must be less than or equal to `7`")
        if 'postal_code' in params and len(params['postal_code']) < 6:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`, length must be greater than or equal to `6`")
        if 'postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['postal_code']):
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'house_number' in params and params['house_number'] > 99999:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`, must be a value less than or equal to `99999`")
        if 'house_number' in params and params['house_number'] < 0:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`, must be a value greater than or equal to `0`")
        if 'other_postal_code' in params and len(params['other_postal_code']) > 7:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`, length must be less than or equal to `7`")
        if 'other_postal_code' in params and len(params['other_postal_code']) < 6:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`, length must be greater than or equal to `6`")
        if 'other_postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['other_postal_code']):
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'other_house_number' in params and params['other_house_number'] > 99999:
            raise ValueError("Invalid value for parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`, must be a value less than or equal to `99999`")
        if 'other_house_number' in params and params['other_house_number'] < 0:
            raise ValueError("Invalid value for parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number`, must be a value greater than or equal to `0`")

        collection_formats = {}

        resource_path = '/addresses/nl/{postalCode}/{houseNumber}/distances/{otherPostalCode}/{otherHouseNumber}'.replace('{format}', 'json')
        path_params = {}
        if 'postal_code' in params:
            path_params['postalCode'] = params['postal_code']
        if 'house_number' in params:
            path_params['houseNumber'] = params['house_number']
        if 'other_postal_code' in params:
            path_params['otherPostalCode'] = params['other_postal_code']
        if 'other_house_number' in params:
            path_params['otherHouseNumber'] = params['other_house_number']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse2001',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix(self, postal_code, house_number, other_postal_code, other_house_number, other_house_number_suffix, **kwargs):
        """
        Get the distance in meters from one address based on Postal Code and HouseNumber to another based on Postal Code, HouseNumber and HouseNumber Suffix
        Retrieves the distance in meters from one address based on Postal Code and Housenumber to another based on Postal Code, HouseNumber and HouseNumber Suffix
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix(postal_code, house_number, other_postal_code, other_house_number, other_house_number_suffix, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int other_house_number: Housenumber (required)
        :param str other_house_number_suffix: HouseNumber Suffix (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix_with_http_info(postal_code, house_number, other_postal_code, other_house_number, other_house_number_suffix, **kwargs)
        else:
            (data) = self.addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix_with_http_info(postal_code, house_number, other_postal_code, other_house_number, other_house_number_suffix, **kwargs)
            return data

    def addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix_with_http_info(self, postal_code, house_number, other_postal_code, other_house_number, other_house_number_suffix, **kwargs):
        """
        Get the distance in meters from one address based on Postal Code and HouseNumber to another based on Postal Code, HouseNumber and HouseNumber Suffix
        Retrieves the distance in meters from one address based on Postal Code and Housenumber to another based on Postal Code, HouseNumber and HouseNumber Suffix
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix_with_http_info(postal_code, house_number, other_postal_code, other_house_number, other_house_number_suffix, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int house_number: Housenumber (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int other_house_number: Housenumber (required)
        :param str other_house_number_suffix: HouseNumber Suffix (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['postal_code', 'house_number', 'other_postal_code', 'other_house_number', 'other_house_number_suffix']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'postal_code' is set
        if ('postal_code' not in params) or (params['postal_code'] is None):
            raise ValueError("Missing the required parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`")
        # verify the required parameter 'house_number' is set
        if ('house_number' not in params) or (params['house_number'] is None):
            raise ValueError("Missing the required parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`")
        # verify the required parameter 'other_postal_code' is set
        if ('other_postal_code' not in params) or (params['other_postal_code'] is None):
            raise ValueError("Missing the required parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`")
        # verify the required parameter 'other_house_number' is set
        if ('other_house_number' not in params) or (params['other_house_number'] is None):
            raise ValueError("Missing the required parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`")
        # verify the required parameter 'other_house_number_suffix' is set
        if ('other_house_number_suffix' not in params) or (params['other_house_number_suffix'] is None):
            raise ValueError("Missing the required parameter `other_house_number_suffix` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`")

        if 'postal_code' in params and len(params['postal_code']) > 7:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`, length must be less than or equal to `7`")
        if 'postal_code' in params and len(params['postal_code']) < 6:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`, length must be greater than or equal to `6`")
        if 'postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['postal_code']):
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'house_number' in params and params['house_number'] > 99999:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`, must be a value less than or equal to `99999`")
        if 'house_number' in params and params['house_number'] < 0:
            raise ValueError("Invalid value for parameter `house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`, must be a value greater than or equal to `0`")
        if 'other_postal_code' in params and len(params['other_postal_code']) > 7:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`, length must be less than or equal to `7`")
        if 'other_postal_code' in params and len(params['other_postal_code']) < 6:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`, length must be greater than or equal to `6`")
        if 'other_postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['other_postal_code']):
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'other_house_number' in params and params['other_house_number'] > 99999:
            raise ValueError("Invalid value for parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`, must be a value less than or equal to `99999`")
        if 'other_house_number' in params and params['other_house_number'] < 0:
            raise ValueError("Invalid value for parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_house_number_to_postal_code_house_number_and_suffix`, must be a value greater than or equal to `0`")

        collection_formats = {}

        resource_path = '/addresses/nl/{postalCode}/{houseNumber}/distances/{otherPostalCode}/{otherHouseNumber}/{otherHouseNumberSuffix}'.replace('{format}', 'json')
        path_params = {}
        if 'postal_code' in params:
            path_params['postalCode'] = params['postal_code']
        if 'house_number' in params:
            path_params['houseNumber'] = params['house_number']
        if 'other_postal_code' in params:
            path_params['otherPostalCode'] = params['other_postal_code']
        if 'other_house_number' in params:
            path_params['otherHouseNumber'] = params['other_house_number']
        if 'other_house_number_suffix' in params:
            path_params['otherHouseNumberSuffix'] = params['other_house_number_suffix']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse2001',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_distance_from_postal_code_to_postal_code(self, postal_code, other_postal_code, **kwargs):
        """
        Get the distance in meters from one address to another based on Postal Code
        Retrieves the distance in meters from one address to another based on Postal Code
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_to_postal_code(postal_code, other_postal_code, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_distance_from_postal_code_to_postal_code_with_http_info(postal_code, other_postal_code, **kwargs)
        else:
            (data) = self.addresses_nl_get_distance_from_postal_code_to_postal_code_with_http_info(postal_code, other_postal_code, **kwargs)
            return data

    def addresses_nl_get_distance_from_postal_code_to_postal_code_with_http_info(self, postal_code, other_postal_code, **kwargs):
        """
        Get the distance in meters from one address to another based on Postal Code
        Retrieves the distance in meters from one address to another based on Postal Code
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_to_postal_code_with_http_info(postal_code, other_postal_code, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['postal_code', 'other_postal_code']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_distance_from_postal_code_to_postal_code" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'postal_code' is set
        if ('postal_code' not in params) or (params['postal_code'] is None):
            raise ValueError("Missing the required parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code`")
        # verify the required parameter 'other_postal_code' is set
        if ('other_postal_code' not in params) or (params['other_postal_code'] is None):
            raise ValueError("Missing the required parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code`")

        if 'postal_code' in params and len(params['postal_code']) > 7:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code`, length must be less than or equal to `7`")
        if 'postal_code' in params and len(params['postal_code']) < 6:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code`, length must be greater than or equal to `6`")
        if 'postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['postal_code']):
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'other_postal_code' in params and len(params['other_postal_code']) > 7:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code`, length must be less than or equal to `7`")
        if 'other_postal_code' in params and len(params['other_postal_code']) < 6:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code`, length must be greater than or equal to `6`")
        if 'other_postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['other_postal_code']):
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")

        collection_formats = {}

        resource_path = '/addresses/nl/{postalCode}/distances/{otherPostalCode}'.replace('{format}', 'json')
        path_params = {}
        if 'postal_code' in params:
            path_params['postalCode'] = params['postal_code']
        if 'other_postal_code' in params:
            path_params['otherPostalCode'] = params['other_postal_code']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse2001',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_distance_from_postal_code_to_postal_code_house_number(self, postal_code, other_postal_code, other_house_number, **kwargs):
        """
        Get the distance in meters from one address based on Postal Code to another based on Postal Code and HouseNumber
        Retrieves the distance in meters from one address based on Postal Code to another based on Postal Code and HouseNumber
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_to_postal_code_house_number(postal_code, other_postal_code, other_house_number, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int other_house_number: Housenumber (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_with_http_info(postal_code, other_postal_code, other_house_number, **kwargs)
        else:
            (data) = self.addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_with_http_info(postal_code, other_postal_code, other_house_number, **kwargs)
            return data

    def addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_with_http_info(self, postal_code, other_postal_code, other_house_number, **kwargs):
        """
        Get the distance in meters from one address based on Postal Code to another based on Postal Code and HouseNumber
        Retrieves the distance in meters from one address based on Postal Code to another based on Postal Code and HouseNumber
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_with_http_info(postal_code, other_postal_code, other_house_number, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int other_house_number: Housenumber (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['postal_code', 'other_postal_code', 'other_house_number']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_distance_from_postal_code_to_postal_code_house_number" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'postal_code' is set
        if ('postal_code' not in params) or (params['postal_code'] is None):
            raise ValueError("Missing the required parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number`")
        # verify the required parameter 'other_postal_code' is set
        if ('other_postal_code' not in params) or (params['other_postal_code'] is None):
            raise ValueError("Missing the required parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number`")
        # verify the required parameter 'other_house_number' is set
        if ('other_house_number' not in params) or (params['other_house_number'] is None):
            raise ValueError("Missing the required parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number`")

        if 'postal_code' in params and len(params['postal_code']) > 7:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number`, length must be less than or equal to `7`")
        if 'postal_code' in params and len(params['postal_code']) < 6:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number`, length must be greater than or equal to `6`")
        if 'postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['postal_code']):
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'other_postal_code' in params and len(params['other_postal_code']) > 7:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number`, length must be less than or equal to `7`")
        if 'other_postal_code' in params and len(params['other_postal_code']) < 6:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number`, length must be greater than or equal to `6`")
        if 'other_postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['other_postal_code']):
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'other_house_number' in params and params['other_house_number'] > 99999:
            raise ValueError("Invalid value for parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number`, must be a value less than or equal to `99999`")
        if 'other_house_number' in params and params['other_house_number'] < 0:
            raise ValueError("Invalid value for parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number`, must be a value greater than or equal to `0`")

        collection_formats = {}

        resource_path = '/addresses/nl/{postalCode}/distances/{otherPostalCode}/{otherHouseNumber}'.replace('{format}', 'json')
        path_params = {}
        if 'postal_code' in params:
            path_params['postalCode'] = params['postal_code']
        if 'other_postal_code' in params:
            path_params['otherPostalCode'] = params['other_postal_code']
        if 'other_house_number' in params:
            path_params['otherHouseNumber'] = params['other_house_number']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse2001',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix(self, postal_code, other_postal_code, other_house_number, other_house_number_suffix, **kwargs):
        """
        Get the distance in meters from one address based on Postal Code to another based on Postal Code, HouseNumber and HouseNumber Suffix
        Retrieves the distance in meters from one address based on Postal Code to another based on Postal Code, HouseNumber and HouseNumber Suffix
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix(postal_code, other_postal_code, other_house_number, other_house_number_suffix, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int other_house_number: Housenumber (required)
        :param str other_house_number_suffix: HouseNumber Suffix (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix_with_http_info(postal_code, other_postal_code, other_house_number, other_house_number_suffix, **kwargs)
        else:
            (data) = self.addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix_with_http_info(postal_code, other_postal_code, other_house_number, other_house_number_suffix, **kwargs)
            return data

    def addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix_with_http_info(self, postal_code, other_postal_code, other_house_number, other_house_number_suffix, **kwargs):
        """
        Get the distance in meters from one address based on Postal Code to another based on Postal Code, HouseNumber and HouseNumber Suffix
        Retrieves the distance in meters from one address based on Postal Code to another based on Postal Code, HouseNumber and HouseNumber Suffix
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix_with_http_info(postal_code, other_postal_code, other_house_number, other_house_number_suffix, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param str other_postal_code: Dutch Postal code (Postcode), consisting of four digits followed by two letters (e.g. 1000AA). A Space between the digits and the letters is allowed but not mandatory. (required)
        :param int other_house_number: Housenumber (required)
        :param str other_house_number_suffix: HouseNumber Suffix (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['postal_code', 'other_postal_code', 'other_house_number', 'other_house_number_suffix']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'postal_code' is set
        if ('postal_code' not in params) or (params['postal_code'] is None):
            raise ValueError("Missing the required parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix`")
        # verify the required parameter 'other_postal_code' is set
        if ('other_postal_code' not in params) or (params['other_postal_code'] is None):
            raise ValueError("Missing the required parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix`")
        # verify the required parameter 'other_house_number' is set
        if ('other_house_number' not in params) or (params['other_house_number'] is None):
            raise ValueError("Missing the required parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix`")
        # verify the required parameter 'other_house_number_suffix' is set
        if ('other_house_number_suffix' not in params) or (params['other_house_number_suffix'] is None):
            raise ValueError("Missing the required parameter `other_house_number_suffix` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix`")

        if 'postal_code' in params and len(params['postal_code']) > 7:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix`, length must be less than or equal to `7`")
        if 'postal_code' in params and len(params['postal_code']) < 6:
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix`, length must be greater than or equal to `6`")
        if 'postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['postal_code']):
            raise ValueError("Invalid value for parameter `postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'other_postal_code' in params and len(params['other_postal_code']) > 7:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix`, length must be less than or equal to `7`")
        if 'other_postal_code' in params and len(params['other_postal_code']) < 6:
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix`, length must be greater than or equal to `6`")
        if 'other_postal_code' in params and not re.search('^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$', params['other_postal_code']):
            raise ValueError("Invalid value for parameter `other_postal_code` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix`, must conform to the pattern `/^[1-9][0-9]{3}\\s?[a-zA-Z]{2}$/`")
        if 'other_house_number' in params and params['other_house_number'] > 99999:
            raise ValueError("Invalid value for parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix`, must be a value less than or equal to `99999`")
        if 'other_house_number' in params and params['other_house_number'] < 0:
            raise ValueError("Invalid value for parameter `other_house_number` when calling `addresses_nl_get_distance_from_postal_code_to_postal_code_house_number_and_suffix`, must be a value greater than or equal to `0`")

        collection_formats = {}

        resource_path = '/addresses/nl/{postalCode}/distances/{otherPostalCode}/{otherHouseNumber}/{otherHouseNumberSuffix}'.replace('{format}', 'json')
        path_params = {}
        if 'postal_code' in params:
            path_params['postalCode'] = params['postal_code']
        if 'other_postal_code' in params:
            path_params['otherPostalCode'] = params['other_postal_code']
        if 'other_house_number' in params:
            path_params['otherHouseNumber'] = params['other_house_number']
        if 'other_house_number_suffix' in params:
            path_params['otherHouseNumberSuffix'] = params['other_house_number_suffix']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/json'])

        # Authentication setting
        auth_settings = ['oauth2_client', 'oauth2_implicit']

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse2001',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)
